<?php
/**
 * @file
 * Implements a page flag.
 */

class flag_page extends flag_flag {

  function default_options() {
    $options = parent::default_options();
    $options += array(
      'override_page_title' => FALSE,
    );
    return $options;
  }

  function options_form(&$form) {
    parent::options_form($form);

    $form['display']['override_page_title'] = array(
      '#type' => 'checkbox',
      '#title' => t('Override the page title when flagging page'),
      '#default_value' => $this->override_page_title,
      '#access' => empty($this->locked['override_page_title']),
    );

    //remove node type setting as irrelevant
    unset($form['types']);
  }

  /**
   * Deletes a page flag from the database.
   */
  function delete() {
    parent::delete();
    db_query('DELETE FROM {flag_page_data} WHERE fid = %d', $this->fid);
    db_query("DELETE FROM {blocks} WHERE module = 'flag_page' and delta = '%s'", $this->name);
  }
  
  /**
   * Validates a flag settings
   */
  function validate() {
    parent::validate();
    $this->validate_override_page_title();
  }

  function validate_override_page_title() {
    if ($this->override_page_title) {
      // Ensure that the display is set to confirmation form.
      if ($this->link_type != 'confirm') {
        form_set_error('link_type', t('If you want to override the page title you must use the confirmation link type'));
      }
    }
  }

  function _load_content($content_id) {
    if ($this->global) {
      $uid = 0;
    }
    else {
      $uid = $GLOBALS['user']->uid;
    }

    $result = db_query("SELECT url, title FROM {flag_page_data} WHERE content_id = %d AND uid = %d AND fid = %d", $content_id, $uid, $this->fid);
    $content[$content_id] = array(
      'content_id' => $content_id,
    );
    $data = db_fetch_object($result);
    if ($data->url) {
      $content[$content_id] = array(
        'url' => $data->url,
        'title' => $data->title,
      );
    }
    return $content;
  }

  function applies_to_content_object($content_id) {
    return TRUE;
  }

  function get_url_from_content_id($content_id) {
    if ($this->global) {
      $uid = 0;
    }
    else {
      $uid = $GLOBALS['user']->uid;
    }
    return db_result(db_query("SELECT url FROM {flag_page_data} WHERE content_id = %d AND uid = %d AND fid = %d", $content_id, $uid, $this->fid));
  }

  function get_content_id($url) {
    if ($this->global) {
      $uid = 0;
    }
    else {
      $uid = $GLOBALS['user']->uid;
    }
    $content_id = db_result(db_query("SELECT content_id FROM {flag_page_data} WHERE url = '%s' AND uid = %d AND fid = %d", $url, $uid, $this->fid));

    if (!$content_id) {
      $menu_item = menu_get_item($url);
      $flag_page_data = array(
        'url' => $url,
        'uid' => $uid,
        'fid' => $this->fid,
        'title' => isset($menu_item['title']) ? $menu_item['title'] : '',
      );
      drupal_write_record('flag_page_data', $flag_page_data);
      $content_id = $flag_page_data['content_id'];
    }
    return $content_id;
  }


/*
 * Not quite sure if these are needed
  function get_labels_token_types() {
    return array('page');
  }

  function replace_tokens($label, $contexts, $content_id) {
    if ($content_id && ($page = $this->fetch_content($content_id))) {
      $contexts['page'] = $page;
    }
    return parent::replace_tokens($label, $contexts, $content_id);
  }

  function get_relevant_action_objects($content_id) {
    return array(
      'page' => $this->fetch_content($content_id),
    );
  }*/


  function get_flag_action($content_id) {
    $flag_action = parent::get_flag_action($content_id);
    $page = $this->fetch_content($content_id);
    $flag_action->content_title = $page->title;
    $flag_action->content_url = _flag_url($page->url);
    return $flag_action;
  }

  function rules_get_event_arguments_definition() {
    return array(
      'term' => array(
        'type' => 'page',
        'label' => t('flagged page'),
        'handler' => 'flag_rules_get_event_argument',
      ),
    );
  }

  function rules_get_element_argument_definition() {
    return array('type' => 'page', 'label' => t('Flagged page'));
  }

  function get_views_info() {
    return array(
      'views table' => 'flag_page_data',
      'join field' => 'content_id',
      'title field' => 'description',
      'title' => t('Page flag'),
      'help' => t('Limit results to only those urls flagged by a certain flag; Or display information about the flag set on a term.'),
      'counter title' => t('Page flag counter'),
      'counter help' => t('Include this to gain access to the flag counter field.'),
    );
  }

  function applies_to_content_id_array($content_ids) {
    $passed = array();
    foreach ($content_ids as $content_id) {
      if ($this->applies_to_content_id($content_id)) {
        $passed[$content_id] = TRUE;
      }
    }
    return $passed;
  }

  //Custom user access to not allow anonymous users to see block is no roles are configured against the flag
  function user_access($account = NULL) {
    if (!isset($account)) {
      $account = $GLOBALS['user'];
    }
    $matched_roles = array_intersect($this->roles, array_keys($account->roles));
    return !empty($matched_roles) || $account->uid == 1;
  }
}