<?php
/**
 * @file
 * Integrates flag_page with views
 */
function flag_page_views_data() {
  // Define the base group of this table. Fields that don't
  // have a group defined will go into this field by default.
  $data = array();

  // ----------------------------------------------------------------------
  // vocabulary table

  $data['flag_page_data']['table']['group']  = t('Flag page');
  $data['flag_page_data']['table']['base'] = array(
    'field' => 'content_id',
    'title' => t('Flag pages'),
    'help' => t('Lists url\'s flagged by Flag pages'),
  );

  $data['flag_page_data']['table']['join'] = array(
    // flag_page_data links to flags via content id
    'flag_content' => array(
      'left_field' => 'fcid',
      'field' => 'content_id',
    ),
  );

  $data['flag_page_data']['content_id'] = array(
    'title' => t('Content ID'),
    'field' => array(
      'help' => t('Content ID of the flagged page.'),
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
  );

  $data['flag_page_data']['url'] = array(
    'title' => t('URL'), // The item it appears as on the UI,
    'field' => array(
      'help' => t('Name of the URL of the flagged page.'),
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
  );
  $data['flag_page_data']['title'] = array(
    'title' => t('Link title'), // The item it appears as on the UI,
    'field' => array(
      'help' => t('The title of the flagged page'),
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
  );

  // uid field
  $data['flag_page_data']['uid'] = array(
    'title' => t('User'),
    'help' => t('Relate a page flag to the user who created the flag.'),
    'relationship' => array(
      'handler' => 'views_handler_relationship',
      'base' => 'users',
      'base field' => 'uid',
      'label' => t('user'),
    ),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
      'help' => t('Sort by user id.'),
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
      'help' => t('Ids of users that created invitations.'),
      'label' => t('User id'),
    ),
  );

  $data['flag_page_data']['flag_page_link'] = array(
    'field' => array(
      'title' => t('Flag page link'),
      'help' => t('Formatted link to flagged page'),
      'handler' => 'views_handler_field_flag_page_link',
    ),
  );

  return $data;
}

function flag_page_views_handlers() {
  return array(
    'info' => array(
      'path' => drupal_get_path('module', 'flag_page') .'/includes',
    ),
    'handlers' => array(
      'views_handler_field_flag_page_link' => array(
        'parent' => 'views_handler_field',
      ),
    ),
  );
}
